@@ -1,9 +1,10 @@
-from __future__ import print_function
-
+"""A Python kernel for Jupyter."""
 from IPython.core.inputtransformer2 import TransformerManager
 from metakernel import MetaKernel
 import sys
 
+__version__ = "0.19.1"
+
 class MetaKernelPython(MetaKernel):
     implementation = 'MetaKernel Python'
     implementation_version = '1.0'
